# altinn3-common-util
A library of handy modules and utilities that can be used and built on when integrating with Altinn 3 and SSB's Altinn 3 data collection solutions

To build package locally during development run (from root directory of project):

python setup.py install